#!/bin/ksh
#
#   Licensed Materials - Property of IBM
#
#   "Restricted Materials of IBM"
#
#   5724-U38, 5724-U39, 5724-U48
#
#   © Copyright IBM Corp. 2018 All Rights Reserved
#
#   © Copyright 2018 UNICOM® Systems, Inc. - All Rights Reserved
#
#   US Government Users Restricted Rights - Use, duplication or
#   disclosure restricted by GSA ADP Schedule Contract with
#   IBM Corp.
#
# Read in rtbuild.h and obtain the necessary version parameters
# Use the directory passed in argument 1 or the directory of this script file.

if [ "$1" = "" ] ; then
    _DIR=$PWD
else
    _DIR=$1
fi
if [ ".$2" = ".clean" ] ; then
    _OPTIONS="cleanonly"
else
    _OPTIONS=""
fi

_RTBUILD="${_DIR}/rtbuild.h"
if [ ! -f ${_RTBUILD} ] ; then
    echo Cannot find ${_RTBUILD}.
    echo Pass the rt/bin directory as the first argument.
    exit 1
fi

if [ ! -f ${_DIR}/createODPPsymboliclinks.sh ] ; then
    echo Cannot find ${_DIR}/createODPPsymboliclinks.sh.
    echo Ensure that the directory ${_DIR} contains the file createODPPsymboliclinks.sh.
    exit 1
fi

# rtbuild.h is created on Windows during the build, so it has DOS format (carriage returns)
# we need to remove those
_RTBUILD2="${_DIR}/rtbuildnew.h"
tr -d '\r' < ${_RTBUILD} > ${_RTBUILD2}
rm ${_RTBUILD}
mv ${_RTBUILD2} ${_RTBUILD}

# Define the the first two version positions (double quoted)
_VER=""
# Default the full version (doupble quoted)
_VERSION=""
# Define the first version position (unquoted)
_VER_V=
# Define the second version position (unquoted) 
_VER_M=

# Set the internal field separator to a space
# Each line is in the form of
# #define name value
IFS=' '
while read -r line define value 
do
    if [ ".${define}" = ".RT_VER_VMR" ] ; then
        _VER=${value}
    elif [ ".${define}" = ".RT_VERSION" ] ; then
        _VERSION=${value}
    elif [ ".${define}" = ".RT_VER_V" ] ; then
        _VER_V=${value}
    elif [ ".${define}" = ".RT_VER_M" ] ; then
        _VER_M=${value}
    fi
done < "${_RTBUILD}"

if [ -z "${_VER}" ] ; then
    echo Unable to find the define RT_VER_VMR in ${_RTBUILD}
fi 
if [ -z "${_VERSION}" ] ; then
    echo Unable to find the define RT_VERSION in ${_RTBUILD}
fi 
if [ -z "${_VER_V}" ] ; then
    echo Unable to find the define RT_VER_V in ${_RTBUILD}
fi 
if [ -z "${_VER_M}" ] ; then
    echo Unable to find the define RT_VER_M in ${_RTBUILD}
fi 

echo Directory=            ${_DIR}
echo 2 Position Version=   ${_VER}
echo Full Version=         ${_VERSION} 
echo 1st version position= ${_VER_V}
echo 2nd version position= ${_VER_M}
echo Stripping quotes...

# Remove surrounding quotes
_QUOTELESS=$(echo ${_VER} | sed -e 's/\"//g')
_VER=${_QUOTELESS}

_QUOTELESS=$(echo ${_VERSION} | sed -e 's/\"//g')
_VERSION=${_QUOTELESS}

echo 2 Position Version=   ${_VER}
echo Full Version=         ${_VERSION} 
echo 1st version position= ${_VER_V}
echo 2nd version position= ${_VER_M}

if [ "${_VERSION}" != "11.3.0.4" ] ; then
    # Remove invalid 11.3.0.4 links
    fullversion=11.3.0.4
    majorver=11.3
    majorvershort=113
    echo Removing symbolic links for $fullversion 

    platform=`uname -s`
    platform_version=`uname -m`

    echo "Platform = $platform"
    echo "Target Directory = $1"
    soname="so"

    #ODPP library symbolic links
    #We will always remove the symbolic link if it exists

   echo "Deleting symbolic links and duplicates for the ODPP libraries"   
   if [ "$platform" = "AIX" ]
   then
      if [[ -L $1/libODPProvider.a || -e $1/libODPProvider.a ]]; then rm $1/libODPProvider.a; fi 
      if [[ -L $1/libODPProvider.$majorver.a || -e $1/libODPProvider.$majorver.a ]]; then rm $1/libODPProvider.$majorver.a; fi 
      if [[ -L $1/libODPPOSLibUnix.a || -e $1/libODPPOSLibUnix.a ]]; then rm $1/libODPPOSLibUnix.a; fi 
      if [[ -L $1/libODPPOSLibUnix.$majorver.a || -e $1/libODPPOSLibUnix.$majorver.a ]]; then rm $1/libODPPOSLibUnix.$majorver.a; fi 
      if [[ -L $1/libODPPEnvLib.a || -e $1/libODPPEnvLib.a ]]; then rm $1/libODPPEnvLib.a; fi 
      if [[ -L $1/libODPPEnvLib.$majorver.a || -e $1/libODPPEnvLib.$majorver.a ]]; then rm $1/libODPPEnvLib.$majorver.a; fi 
      if [[ -L $1/libODPPICULib.a || -e $1/libODPPICULib.a ]]; then rm $1/libODPPICULib.a; fi 
      if [[ -L $1/libODPPICULib.$majorver.a || -e $1/libODPPICULib.$majorver.a ]]; then rm $1/libODPPICULib.$majorver.a; fi 
      if [[ -L $1/libODPPDataCnvLib.a || -e $1/libODPPDataCnvLib.a ]]; then rm $1/libODPPDataCnvLib.a; fi 
      if [[ -L $1/libODPPDataCnvLib.$majorver.a || -e $1/libODPPDataCnvLib.$majorver.a ]]; then rm $1/libODPPDataCnvLib.$majorver.a; fi 
      if [[ -L $1/libODPPXMLReaderLib.a || -e $1/libODPPXMLReaderLib.a ]]; then rm $1/libODPPXMLReaderLib.a; fi 
      if [[ -L $1/libODPPXMLReaderLib.$majorver.a || -e $1/libODPPXMLReaderLib.$majorver.a ]]; then rm $1/libODPPXMLReaderLib.$majorver.a; fi   
      if [[ -L $1/libODPPLicl.a || -e $1/libODPPLicl.a ]]; then rm $1/libODPPLicl.a; fi 
      if [[ -L $1/libODPPLicl.$majorver.a || -e $1/libODPPLicl.$majorver.a ]]; then rm $1/libODPPLicl.$majorver.a; fi 
      if [[ -L $1/libODPCCNPrvLib.a || -e $1/libODPCCNPrvLib.a ]]; then rm $1/libODPCCNPrvLib.a; fi 
      if [[ -L $1/libODPCCNPrvLib.$majorver.a || -e $1/libODPCCNPrvLib.$majorver.a ]]; then rm $1/libODPCCNPrvLib.$majorver.a; fi 
      if [[ -L $1/libODPNIDPrvLib.a || -e $1/libODPNIDPrvLib.a ]]; then rm $1/libODPNIDPrvLib.a; fi 
      if [[ -L $1/libODPNIDPrvLib.$majorver.a || -e $1/libODPNIDPrvLib.$majorver.a ]]; then rm $1/libODPNIDPrvLib.$majorver.a; fi   
      if [[ -L $1/libODPEMLPrvLib.a || -e $1/libODPEMLPrvLib.a ]]; then rm $1/libODPEMLPrvLib.a; fi 
      if [[ -L $1/libODPEMLPrvLib.$majorver.a || -e $1/libODPEMLPrvLib.$majorver.a ]]; then rm $1/libODPEMLPrvLib.$majorver.a; fi 
      if [[ -L $1/libODPCOLPrvLib.a || -e $1/libODPCOLPrvLib.a ]]; then rm $1/libODPCOLPrvLib.a; fi 
      if [[ -L $1/libODPCOLPrvLib.$majorver.a || -e $1/libODPCOLPrvLib.$majorver.a ]]; then rm $1/libODPCOLPrvLib.$majorver.a; fi 
      if [[ -L $1/libODPHASHPrvLib.a || -e $1/libODPHASHPrvLib.a ]]; then rm $1/libODPHASHPrvLib.a; fi 
      if [[ -L $1/libODPHASHPrvLib.$majorver.a || -e $1/libODPHASHPrvLib.$majorver.a ]]; then rm $1/libODPHASHPrvLib.$majorver.a; fi   
      if [[ -L $1/libODPAGEPrvLib.a || -e $1/libODPAGEPrvLib.a ]]; then rm $1/libODPAGEPrvLib.a; fi 
      if [[ -L $1/libODPAGEPrvLib.$majorver.a || -e $1/libODPAGEPrvLib.$majorver.a ]]; then rm $1/libODPAGEPrvLib.$majorver.a; fi 
      if [[ -L $1/libODPPLDSDB2Lib.a || -e $1/libODPPLDSDB2Lib.a ]]; then rm $1/libODPPLDSDB2Lib.a; fi 
      if [[ -L $1/libODPPLDSDB2Lib.$majorver.a || -e $1/libODPPLDSDB2Lib.$majorver.a ]]; then rm $1/libODPPLDSDB2Lib.$majorver.a; fi  
      if [[ -L $1/libODPLKPPrvLib.a || -e $1/libODPLKPPrvLib.a ]]; then rm $1/libODPLKPPrvLib.a; fi 
      if [[ -L $1/libODPLKPPrvLib.$majorver.a || -e $1/libODPLKPPrvLib.$majorver.a ]]; then rm $1/libODPLKPPrvLib.$majorver.a; fi  
      if [[ -L $1/libODPPAdapter.a || -e $1/libODPPAdapter.a ]]; then rm $1/libODPPAdapter.a; fi 
      if [[ -L $1/libODPPAdapter.$majorver.a || -e $1/libODPPAdapter.$majorver.a ]]; then rm $1/libODPPAdapter.$majorver.a; fi  
      if [[ -L $1/libODPPParser.a || -e $1/libODPPParser.a ]]; then rm $1/libODPPParser.a; fi 
      if [[ -L $1/libODPPParser.$majorver.a || -e $1/libODPPParser.$majorver.a ]]; then rm $1/libODPPParser.$majorver.a; fi  
      if [[ -L $1/libODPPErrorHandler.a || -e $1/libODPPErrorHandler.a ]]; then rm $1/libODPPErrorHandler.a; fi 
      if [[ -L $1/libODPPErrorHandler.$majorver.a || -e $1/libODPPErrorHandler.$majorver.a ]]; then rm $1/libODPPErrorHandler.$majorver.a; fi   
      if [[ -L $1/libODPPInstMgr.a || -e $1/libODPPInstMgr.a ]]; then rm $1/libODPPInstMgr.a; fi 
      if [[ -L $1/libODPPInstMgr.$majorver.a || -e $1/libODPPInstMgr.$majorver.a ]]; then rm $1/libODPPInstMgr.$majorver.a; fi
      if [[ -L $1/libioqhash.a || -e $1/libioqhash.a ]]; then rm $1/libioqhash.a; fi 
      if [[ -L $1/libioqhash.$majorver.a || -e $1/libioqhash.$majorver.a ]]; then rm $1/libioqhash.$majorver.a; fi
      if [[ -L $1/libioqldsoralib.a || -e $1/libioqldsoralib.a ]]; then rm $1/libioqldsoralib.a; fi 
      if [[ -L $1/libioqldsoralib.$majorver.a || -e $1/libioqldsoralib.$majorver.a ]]; then rm $1/libioqldsoralib.$majorver.a; fi
      if [[ -L $1/libODPPLoader.a || -e $1/libODPPLoader.a ]]; then rm $1/libODPPLoader.a; fi 
      if [[ -L $1/libODPPLoader.$majorver.a || -e $1/libODPPLoader.$majorver.a ]]; then rm $1/libODPPLoader.$majorver.a; fi
      if [[ -L $1/libioqspe.$majorver.a || -e $1/libioqspe.$majorver.a ]]; then rm $1/libioqspe.$majorver.a; fi
   else
      if [[ -L $1/libODPProvider.${soname} || -e $1/libODPProvider.${soname} ]]; then rm $1/libODPProvider.${soname}; fi       
      if [[ -L $1/libODPProvider.${soname}.$majorver || -e $1/libODPProvider.${soname}.$majorver ]]; then rm $1/libODPProvider.${soname}.$majorver; fi 
      if [[ -L $1/libODPProvider.$majorver.${soname} || -e $1/libODPProvider.$majorver.${soname} ]]; then rm $1/libODPProvider.$majorver.${soname}; fi 
      if [[ -L $1/libODPPLDSDB2Lib.${soname} || -e $1/libODPPLDSDB2Lib.${soname} ]]; then rm $1/libODPPLDSDB2Lib.${soname}; fi       
      if [[ -L $1/libODPPLDSDB2Lib.${soname}.$majorver || -e $1/libODPPLDSDB2Lib.${soname}.$majorver ]]; then rm $1/libODPPLDSDB2Lib.${soname}.$majorver; fi 
      if [[ -L $1/libODPLKPPrvLib.${soname} || -e $1/libODPLKPPrvLib.${soname} ]]; then rm $1/libODPLKPPrvLib.${soname}; fi 
      if [[ -L $1/libODPLKPPrvLib.${soname}.$majorver || -e $1/libODPLKPPrvLib.${soname}.$majorver ]]; then rm $1/libODPLKPPrvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPAGEPrvLib.${soname} || -e $1/libODPAGEPrvLib.${soname} ]]; then rm $1/libODPAGEPrvLib.${soname}; fi 
      if [[ -L $1/libODPAGEPrvLib.${soname}.$majorver || -e $1/libODPAGEPrvLib.${soname}.$majorver ]]; then rm $1/libODPAGEPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPHASHPrvLib.${soname} || -e $1/libODPHASHPrvLib.${soname} ]]; then rm $1/libODPHASHPrvLib.${soname}; fi       
      if [[ -L $1/libODPHASHPrvLib.${soname}.$majorver || -e $1/libODPHASHPrvLib.${soname}.$majorver ]]; then rm $1/libODPHASHPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPCOLPrvLib.${soname} || -e $1/libODPCOLPrvLib.${soname} ]]; then rm $1/libODPCOLPrvLib.${soname}; fi 
      if [[ -L $1/libODPCOLPrvLib.${soname}.$majorver || -e $1/libODPCOLPrvLib.${soname}.$majorver ]]; then rm $1/libODPCOLPrvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPEMLPrvLib.${soname} || -e $1/libODPEMLPrvLib.${soname} ]]; then rm $1/libODPEMLPrvLib.${soname}; fi 
      if [[ -L $1/libODPEMLPrvLib.${soname}.$majorver || -e $1/libODPEMLPrvLib.${soname}.$majorver ]]; then rm $1/libODPEMLPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPNIDPrvLib.${soname} || -e $1/libODPNIDPrvLib.${soname} ]]; then rm $1/libODPNIDPrvLib.${soname}; fi       
      if [[ -L $1/libODPNIDPrvLib.${soname}.$majorver || -e $1/libODPNIDPrvLib.${soname}.$majorver ]]; then rm $1/libODPNIDPrvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPCCNPrvLib.${soname} || -e $1/libODPCCNPrvLib.${soname} ]]; then rm $1/libODPCCNPrvLib.${soname}; fi 
      if [[ -L $1/libODPCCNPrvLib.${soname}.$majorver || -e $1/libODPCCNPrvLib.${soname}.$majorver ]]; then rm $1/libODPCCNPrvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPPLicl.${soname} || -e $1/libODPPLicl.${soname} ]]; then rm $1/libODPPLicl.${soname}; fi 
      if [[ -L $1/libODPPLicl.${soname}.$majorver || -e $1/libODPPLicl.${soname}.$majorver ]]; then rm $1/libODPPLicl.${soname}.$majorver; fi 
      if [[ -L $1/libODPPXMLReaderLib.${soname} || -e $1/libODPPXMLReaderLib.${soname} ]]; then rm $1/libODPPXMLReaderLib.${soname}; fi       
      if [[ -L $1/libODPPXMLReaderLib.${soname}.$majorver || -e $1/libODPPXMLReaderLib.${soname}.$majorver ]]; then rm $1/libODPPXMLReaderLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPPDataCnvLib.${soname} || -e $1/libODPPDataCnvLib.${soname} ]]; then rm $1/libODPPDataCnvLib.${soname}; fi 
      if [[ -L $1/libODPPDataCnvLib.${soname}.$majorver || -e $1/libODPPDataCnvLib.${soname}.$majorver ]]; then rm $1/libODPPDataCnvLib.${soname}.$majorver; fi 
      if [[ -L $1/libODPPICULib.${soname} || -e $1/libODPPICULib.${soname} ]]; then rm $1/libODPPICULib.${soname}; fi       
      if [[ -L $1/libODPPICULib.${soname}.$majorver || -e $1/libODPPICULib.${soname}.$majorver ]]; then rm $1/libODPPICULib.${soname}.$majorver; fi 
      if [[ -L $1/libODPPEnvLib.${soname} || -e $1/libODPPEnvLib.${soname} ]]; then rm $1/libODPPEnvLib.${soname}; fi 
      if [[ -L $1/libODPPEnvLib.${soname}.$majorver || -e $1/libODPPEnvLib.${soname}.$majorver ]]; then rm $1/libODPPEnvLib.${soname}.$majorver; fi       
      if [[ -L $1/libODPPOSLibUnix.${soname} || -e $1/libODPPOSLibUnix.${soname} ]]; then rm $1/libODPPOSLibUnix.${soname}; fi 
      if [[ -L $1/libODPPOSLibUnix.${soname}.$majorver || -e $1/libODPPOSLibUnix.${soname}.$majorver ]]; then rm $1/libODPPOSLibUnix.${soname}.$majorver; fi     
      if [[ -L $1/libODPPAdapter.${soname} || -e $1/libODPPAdapter.${soname} ]]; then rm $1/libODPPAdapter.${soname}; fi 
      if [[ -L $1/libODPPAdapter.${soname}.$majorver || -e $1/libODPPAdapter.${soname}.$majorver ]]; then rm $1/libODPPAdapter.${soname}.$majorver; fi     
      if [[ -L $1/libODPPParser.${soname} || -e $1/libODPPParser.${soname} ]]; then rm $1/libODPPParser.${soname}; fi 
      if [[ -L $1/libODPPParser.${soname}.$majorver || -e $1/libODPPParser.${soname}.$majorver ]]; then rm $1/libODPPParser.${soname}.$majorver; fi     
      if [[ -L $1/libODPPErrorHandler.${soname}.$majorver || -e $1/libODPPErrorHandler.${soname}.$majorver ]]; then rm $1/libODPPErrorHandler.${soname}.$majorver; fi     
      if [[ -L $1/libODPPErrorHandler.$majorver || -e $1/libODPPErrorHandler.$majorver ]]; then rm $1/libODPPErrorHandler.$majorver; fi     
      if [[ -L $1/libODPPInstMgr.${soname}.$majorver || -e $1/libODPPInstMgr.${soname}.$majorver ]]; then rm $1/libODPPInstMgr.${soname}.$majorver; fi     
      if [[ -L $1/libODPPInstMgr.$majorver || -e $1/libODPPInstMgr.$majorver ]]; then rm $1/libODPPInstMgr.$majorver; fi     
      if [[ -L $1/libioqhash.${soname} || -e $1/libioqhash.${soname} ]]; then rm $1/libioqhash.${soname}; fi 
      if [[ -L $1/libioqhash.${soname}.$majorver || -e $1/libioqhash.${soname}.$majorver ]]; then rm $1/libioqhash.${soname}.$majorver; fi      
      if [[ -L $1/libioqldsoralib.${soname} || -e $1/libioqldsoralib.${soname} ]]; then rm $1/libioqldsoralib.${soname}; fi 
      if [[ -L $1/libioqldsoralib.${soname}.$majorver || -e $1/libioqldsoralib.${soname}.$majorver ]]; then rm $1/libioqldsoralib.${soname}.$majorver; fi     
      if [[ -L $1/libODPPLoader.${soname} || -e $1/libODPPLoader.${soname} ]]; then rm $1/libODPPLoader.${soname}; fi 
      if [[ -L $1/libODPPLoader.${soname}.$majorver || -e $1/libODPPLoader.${soname}.$majorver ]]; then rm $1/libODPPLoader.${soname}.$majorver; fi 
      if [[ -L $1/libioqspe.${soname}.$majorver || -e $1/libioqspe.${soname}.$majorver ]]; then rm $1/libioqspe.${soname}.$majorver; fi 
   fi

    #XML4C Symbolic Links
      
   echo "Deleting symbolic links and duplicates for the XML4C libraries"   
   if [ "$platform" = "AIX" ]
   then
      #if [[ -L $1/libicudata.a || -e $1/libicudata.a ]]; then rm $1/libicudata.a; fi 
      if [[ -L $1/libicudata38.a || -e $1/libicudata38.a ]]; then rm $1/libicudata38.a; fi 
      if [[ -L $1/libicui18n.a || -e $1/libicui18n.a ]]; then rm $1/libicui18n.a; fi 
      if [[ -L $1/libicui18n38.a || -e $1/libicui18n38.a ]]; then rm $1/libicui18n38.a; fi 
      #if [[ -L $1/libicuuc.a || -e $1/libicuuc.a ]]; then rm $1/libicuuc.a; fi 
      if [[ -L $1/libicuuc38.a || -e $1/libicuuc38.a ]]; then rm $1/libicuuc38.a; fi 
      if [[ -L $1/libXML4CMessages57.a || -e $1/libXML4CMessages57.a ]]; then rm $1/libXML4CMessages57.a; fi 
      if [[ -L $1/libXML4CMessages.a || -e $1/libXML4CMessages.a ]]; then rm $1/libXML4CMessages.a; fi 
      if [[ -L $1/libxml4c-depdom57.a || -e $1/libxml4c-depdom57.a ]]; then rm $1/libxml4c-depdom57.a; fi 
      if [[ -L $1/libxml4c-depdom.a || -e $1/libxml4c-depdom.a ]]; then rm $1/libxml4c-depdom.a; fi 
      if [[ -L $1/libxml4c57.a || -e $1/libxml4c57.a ]]; then rm $1/libxml4c57.a; fi 
      if [[ -L $1/libxml4c.a || -e $1/libxml4c.a ]]; then rm $1/libxml4c.a; fi       
   else
      #OPTDIS: libicudata.so -> libicudata.so.48.0   
      #if [[ -L $1/libicudata.${soname} || -e $1/libicudata.${soname} ]]; then rm $1/libicudata.${soname}; fi       
      if [[ -L $1/libicudata.${soname}.38 || -e $1/libicudata.${soname}.38 ]]; then rm $1/libicudata.${soname}.38; fi 
      if [[ -L $1/libicui18n.${soname} || -e $1/libicui18n.${soname} ]]; then rm $1/libicui18n.${soname}; fi 
      if [[ -L $1/libicui18n.${soname}.38 || -e $1/libicui18n.${soname}.38 ]]; then rm $1/libicui18n.${soname}.38; fi       
      #OPTDIS: libicuuc.so -> libicuuc.so.48.0
      #if [[ -L $1/libicuuc.${soname} || -e $1/libicuuc.${soname} ]]; then rm $1/libicuuc.${soname}; fi 
      if [[ -L $1/libicuuc.${soname}.38 || -e $1/libicuuc.${soname}.38 ]]; then rm $1/libicuuc.${soname}.38; fi 
      if [[ -L $1/libxml4c-depdom.${soname}.57 || -e $1/libxml4c-depdom.${soname}.57 ]]; then rm $1/libxml4c-depdom.${soname}.57; fi 
      if [[ -L $1/libxml4c-depdom.${soname} || -e $1/libxml4c-depdom.${soname} ]]; then rm $1/libxml4c-depdom.${soname}; fi       
      if [[ -L $1/libXML4CMessages.${soname}.57 || -e $1/libXML4CMessages.${soname}.57 ]]; then rm $1/libXML4CMessages.${soname}.57; fi       
      if [[ -L $1/libXML4CMessages57.${soname} || -e $1/libXML4CMessages57.${soname} ]]; then rm $1/libXML4CMessages57.${soname}; fi  
      if [[ -L $1/libXML4CMessages.${soname} || -e $1/libXML4CMessages.${soname} ]]; then rm $1/libXML4CMessages.${soname}; fi       
      if [[ -L $1/libxml4c.${soname}.57 || -e $1/libxml4c.${soname}.57 ]]; then rm $1/libxml4c.${soname}.57; fi       
      if [[ -L $1/libxml4c.${soname} || -e $1/libxml4c.${soname} ]]; then rm $1/libxml4c.${soname}; fi             
   fi

   if [ "$platform" = "AIX" ]
   then
      #ICU 4.8 Symbolic Links
      echo "Deleting symbolic links and duplicates for the ICU 48 libraries"  

      if [[ -L $1/libicudata48.a || -e $1/libicudata48.a ]]; then rm $1/libicudata48.a; fi
      if [[ -L $1/libicuuc48.a || -e $1/libicuuc48.a ]]; then rm $1/libicuuc48.a; fi
      if [[ -L $1/libicudata.a || -e $1/libicudata.a ]]; then rm $1/libicudata.a; fi 
      if [[ -L $1/libicuuc.a || -e $1/libicuuc.a ]]; then rm $1/libicuuc.a; fi 
   else
      echo "Deleting the Optim Distributed symbolic link for the ODPProvider library"   
      if [[ -L $1/libODPPro$majorvershort.${soname} || -e $1/libODPPro$majorvershort.${soname} ]]; then rm $1/libODPPro$majorvershort.${soname}; fi             
      if [[ -L $1/libODPPsr$majorvershort.${soname} || -e $1/libODPPsr$majorvershort.${soname} ]]; then rm $1/libODPPsr$majorvershort.${soname}; fi             
      if [[ -L $1/libODPAdp$majorvershort.${soname} || -e $1/libODPAdp$majorvershort.${soname} ]]; then rm $1/libODPAdp$majorvershort.${soname}; fi             
      if [[ -L $1/libODPErrHnd$majorvershort.${soname} || -e $1/libODPErrHnd$majorvershort.${soname} ]]; then rm $1/libODPErrHnd$majorvershort.${soname}; fi             
      if [[ -L $1/libODPInstMgr$majorvershort.${soname} || -e $1/libODPInstMgr$majorvershort.${soname} ]]; then rm $1/libODPInstMgr$majorvershort.${soname}; fi             
      if [[ -L $1/libODPLicl$majorvershort.${soname} || -e $1/libODPLicl$majorvershort.${soname} ]]; then rm $1/libODPLicl$majorvershort.${soname}; fi  
      if [[ -L $1/libioqhash$majorvershort.${soname} || -e $1/libioqhash$majorvershort.${soname} ]]; then rm $1/libioqhash$majorvershort.${soname}; fi                      
   fi
fi

_SHELL=sh
echo "Detecting OS..."
case ${platform} in
SunOS)
   if [ -f /usr/xpg4/bin/sh ]
   then
      _SHELL=/usr/xpg4/bin/sh
   else
      _SHELL=sh
   fi
   ;;
*)
   ;;
esac

echo _SHELL = ${_SHELL}
if [ -z "${_OPTIONS}" ]
then
    echo Creating symbolic links for ${_VERSION}
fi
${_SHELL} ${_DIR}/createODPPsymboliclinks.sh ${_DIR}  ${_VER}  ${_VERSION} ${_VER_V}${_VER_M} ${_OPTIONS}
